@@ -3,7 +3,6 @@ import os
 import sys
 import liquidluck
 from liquidluck.tools import theme
-from liquidluck.tools import creator
 from liquidluck.tools import webhook
 from liquidluck.tools import server
 from liquidluck import generator
@@ -19,7 +18,7 @@ Usage:
     liquidluck build [-s <file>|--settings=<file>] [-v|--verbose]
     liquidluck server [-s <file>|--settings=<file>] [-p <port>|--port=<port>]
     liquidluck search [<theme>] [-c|--clean] [-f|--force]
-    liquidluck install <theme>
+    liquidluck install <theme> [-g|--global]
     liquidluck webhook (start|stop|restart) %(webhook)s
     liquidluck -h | --help
     liquidluck --version
@@ -31,6 +30,7 @@ Options:
     -p --port=<port>        specify the server port.
     -f --force              search a theme without cache
     -c --clean              show theme name only.
+    -g --global             install theme to global theme folder.
     --version               show version.
 """ % {
     'version': liquidluck.__version__,
@@ -78,9 +78,10 @@ Options:
 
 documentation['install'] = """
 Usage:
-    liquidluck install <theme>
+    liquidluck install <theme> [-g|--global]
 
 Options:
+    -g --global             install theme to global theme folder.
     -h --help               show this screen.
 """
 
@@ -109,49 +110,51 @@ def main():
             version='Felix Felicis v%s' % liquidluck.__version__
         )
 
+    arg_settings = args.get('--settings') or generator.find_settings()
+    arg_verbose = args.get('--verbose')
+    arg_port = int(args.get('--port') or 8000)
+
+    arg_theme = args.get('<theme>') or None
+    arg_clean = args.get('--clean')
+    arg_force = args.get('--force')
+    arg_global = args.get('--global')
+
     if command == 'create':
-        creator.create(args['--settings'] or 'settings.py')
+        generator.create_settings(arg_settings)
     elif command == 'build':
-        arg_settings = args['--settings'] or 'settings.py'
-        if not os.path.exists(arg_settings):
+        if not arg_settings:
             answer = raw_input(
                 "Can't find your setting files, "
                 "would you like to create one?(Y/n) "
             )
             if answer.lower() == 'n':
                 return
-            creator.create(arg_settings)
+            generator.create_settings(arg_settings)
         else:
-            g.detail_logging = args['--verbose']
+            g.detail_logging = arg_verbose
             generator.build(arg_settings)
     elif command == 'server':
-        arg_settings = args['--settings'] or 'settings.py'
-        arg_port = int(args['--port'] or 8000)
         if not os.path.exists(arg_settings):
             print('setting file not found')
             server.config(arg_port)
             server.start_server()
         else:
             generator.load_settings(arg_settings)
-        if settings.permalink.endswith('.html'):
-            permalink = 'html'
-        elif settings.permalink.endswith('/'):
-            permalink = 'slash'
+
+        permalink = settings.config.get('permalink')
+        if permalink.endswith('.html'):
+            _type = 'html'
+        elif permalink.endswith('/'):
+            _type = 'slash'
         else:
-            permalink = 'clean'
-        server.config(arg_port, g.output_directory, permalink)
+            _type = 'clean'
+        server.config(arg_port, g.output_directory, _type)
         server.start_server()
     elif command == 'search':
-        arg_theme = args['<theme>'] or None
-        arg_clean = args['--clean']
-        arg_force = args['--force']
         theme.search(arg_theme, arg_clean, arg_force)
     elif command == 'install':
-        arg_theme = args['<theme>'] or None
-        theme.install(arg_theme)
+        theme.install(arg_theme, arg_global)
     elif command == 'webhook':
-        arg_settings = args['--settings'] or 'settings.py'
-        arg_port = int(args['--port'] or 9000)
         action = (args['start'] and 'start') or (args['stop'] and 'stop') \
                 or (args['restart'] and 'restart')
         webhook.webhook(arg_port, action, arg_settings)
