@@ -51,7 +51,8 @@ class BaseReader(object):
         return False
 
     def get(self, key, value=None):
-        return settings.readers_variables.get(key, value)
+        variables = settings.reader.get('vars') or {}
+        return variables.get(key, value)
 
     @property
     def post_class(self):
@@ -96,7 +97,8 @@ class Post(object):
 
     @property
     def author(self):
-        return Author(self.meta.get('author', settings.author))
+        author = settings.author.get('default', 'admin')
+        return Author(self.meta.get('author', author))
 
     @property
     def embed_author(self):
@@ -167,6 +169,10 @@ class Post(object):
             return path[len(g.source_directory) + 1:]
         return path
 
+    @property
+    def clean_folder(self):
+        return os.path.split(self.clean_filepath)[0]
+
     def __getattr__(self, key):
         try:
             return super(Post, self).__getattr__(key)
@@ -180,7 +186,7 @@ class Author(object):
     def __init__(self, author):
         self.author = author
 
-        __ = settings.authors or {}
+        __ = settings.author.get('vars') or {}
         self._d = __.get(author, {})
 
     def __str__(self):
