@@ -62,15 +62,23 @@ class MarkdownReader(BaseReader):
 
         f.close()
 
+        body = to_unicode(body)
         meta = self._parse_meta(header)
         #: keep body in meta data as source text
         meta['source_text'] = body
+        _toc = m.Markdown(m.HtmlTocRenderer(), 0)
+        meta['toc'] = _toc.render(body)
         content = markdown(body)
         return self.post_class(self.filepath, content, meta=meta)
 
     def _parse_meta(self, header):
         header = m.html(to_unicode(header))
-        title = re.findall(r'<h1>(.*)</h1>', header)[0]
+        titles = re.findall(r'<h1>(.*)</h1>', header)
+        if not titles:
+            logging.error('There is no title')
+            title = None
+        else:
+            title = titles[0]
 
         meta = {'title': title}
         items = re.findall(r'<li>(.*?)</li>', header, re.S)
@@ -111,9 +119,10 @@ class JuneRender(m.HtmlRenderer, m.SmartyPants):
         else:
             html = ''
 
+        variables = settings.reader.get('vars') or {}
         formatter = HtmlFormatter(
-            noclasses=settings.get('highlight_inline', False),
-            linenos=settings.get('highlight_linenos', False),
+            noclasses=variables.get('highlight_inline', False),
+            linenos=variables.get('highlight_linenos', False),
         )
         html += highlight(text, lexer, formatter)
         return html
@@ -122,7 +131,8 @@ class JuneRender(m.HtmlRenderer, m.SmartyPants):
         if is_email:
             return '<a href="mailto:%(link)s">%(link)s</a>' % {'link': link}
 
-        for func in settings.readers_variables.get(
+        variables = settings.reader.get('vars') or {}
+        for func in variables.get(
             'markdown_transform', [
                 'liquidluck.readers.markdown.transform_youtube',
                 'liquidluck.readers.markdown.transform_gist',
@@ -140,7 +150,7 @@ def markdown(text):
     text = to_unicode(text)
     text = re.sub(r'````(.+)', r'````\1+', text)
 
-    render = JuneRender(flags=m.HTML_USE_XHTML)
+    render = JuneRender(flags=m.HTML_USE_XHTML | m.HTML_TOC)
     md = m.Markdown(
         render,
         extensions=(
