@@ -78,11 +78,14 @@ class BaseWriter(object):
         return
 
     def get(self, key, value=None):
-        return settings.writers_variables.get(key, value)
+        variables = settings.writer.get('vars')
+        if isinstance(variables, dict):
+            return variables.get(key, value)
+        return value
 
     @property
     def perpage(self):
-        return settings.perpage
+        return settings.config['perpage']
 
 
 class Pagination(object):
@@ -132,6 +135,20 @@ class Pagination(object):
         return self.total_items[start:end]
 
 
+def find_theme():
+    theme_name = settings.theme.get('name', 'default')
+    theme_gallary = [
+        os.path.join(os.path.abspath('_themes'), theme_name),
+        os.path.expanduser('~/.liquidluck-themes/%s' % theme_name),
+        os.path.join(g.liquid_directory, '_themes', theme_name),
+    ]
+    for path in theme_gallary:
+        if os.path.exists(path):
+            return path
+
+    raise Exception("Can't find theme: %s" % theme_name)
+
+
 def load_jinja():
     #: prepare loaders
     #: loaders = ['_templates', theme]
@@ -140,11 +157,7 @@ def load_jinja():
     if os.path.exists(tpl):
         loaders.append(tpl)
 
-    theme = os.path.join(os.path.abspath('_themes'), settings.theme)
-    if not os.path.exists(theme):
-        theme = os.path.join(g.liquid_directory, '_themes', settings.theme)
-    if not os.path.exists(theme):
-        logging.error("Can't find theme: %s" % settings.theme)
+    theme = find_theme()
 
     #: global variable
     g.theme_directory = theme
@@ -164,7 +177,7 @@ def load_jinja():
     jinja = Environment(
         loader=FileSystemLoader(loaders),
         autoescape=False,  # blog don't need autoescape
-        extensions=settings.template_extensions or [],
+        extensions=settings.writer.get('extensions') or [],
     )
     #: initialize globals
     jinja.globals = {}
@@ -172,7 +185,7 @@ def load_jinja():
     #: load template variables
     jinja.globals.update({
         'site': settings.site,
-        'template': settings.template_variables,
+        'template': settings.template.get("vars") or {},
     })
 
     #: load theme variables
@@ -182,9 +195,9 @@ def load_jinja():
         execfile(theme_config, {}, config)
 
     #: user can reset theme variables
-    config.update(settings.theme_variables)
+    config.update(settings.theme.get('vars') or {})
     #: keep namespace to the latest variables
-    settings.theme_variables = config
+    settings.theme['vars'] = config
     jinja.globals.update({'theme': config})
 
     #: default variables
@@ -213,7 +226,7 @@ def load_jinja():
     jinja.filters.update(config)
 
     #: load filters from settings
-    filters = settings.template_filters or {}
+    filters = settings.template.get("filters") or {}
     for k, v in filters.items():
         jinja.filters.update({k: import_object(v)})
 
@@ -278,11 +291,11 @@ def get_post_destination(post, slug_format):
 @contextfilter
 def permalink(ctx, post, prepend_site=False):
     writer = ctx.get('writer')
-    slug = get_post_slug(post, settings.permalink)
+    slug = get_post_slug(post, settings.config["permalink"])
 
     if prepend_site:
         url = '%s/%s' % (settings.site['url'].rstrip('/'), slug)
-    elif settings.use_relative_url and writer:
+    elif settings.config['relative_url'] and writer:
         base = get_relative_base(writer['filepath'])
         url = '%s/%s' % (base, slug)
     else:
